# abha
It is important to standardize the process of identification of an individual across healthcare providers, to ensure that the created medical records are issued to the right individual or accessed by a Health Information User through appropriate consent. In order to issue an ABHA Number to an individual, one only needs basic demographic details like Name, Year of Birth, Gender. In addition, citizens should be able to update contact information easily. The ABHA Number will be used for the purposes of uniquely identifying persons and authenticating them. An ABHA Address will be used for threading their health records (only with the informed consent of the patient) across multiple systems and stakeholders.
 
Notes:
  1. In case you want to consume the ABHA APIs and use creation on your own interface, use authentication methods as OTP only.
  2. In order to have access to ABHA APIs, your clientId must have hid role in gateway. So if you want access to these APIs then please request it in your ABDM on-boarding request.
  3. In order to have access to Integrated Programs ABHA APIs, your clientId must have integrated_program role in gateway. So if you want access to these APIs then please request it in your ABDM on-boarding request. Also you will need to share integrated program benefit name to be used in this case.
  4. When calling APIs, please ensure that Authorization header must have format as Bearer {Token_Value}. Please note that prefix Bearer is followed by space before the token value.
   

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v3
- Package version: 1.0.0
- Generator version: 7.5.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/Technoculture/ABDM-ABHA-SDK/tree/dev
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/Technoculture/ABDM-ABHA-SDK/tree/dev`)

Then import the package:
```python
import abha
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import abha
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import abha
from abha.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://abhasbx.abdm.gov.in/abha/api/v3
# See configuration.py for a list of all supported configuration parameters.
configuration = abha.Configuration(
    host = "https://abhasbx.abdm.gov.in/abha/api/v3"
)



# Enter a context with an instance of the API client
with abha.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = abha.ABHAEnrollmentApi(api_client)
    request_id = 'request_id_example' # str | 
    timestamp = 'timestamp_example' # str | 
    body = 'body_example' # str |  (optional)

    try:
        # AUTH - OF AADHAAR OTP FOR PARENT VERIFICATION
        api_response = api_instance.api_v3_enrollment_auth_by_aadhaar_post(request_id, timestamp, body=body)
        print("The response of ABHAEnrollmentApi->api_v3_enrollment_auth_by_aadhaar_post:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ABHAEnrollmentApi->api_v3_enrollment_auth_by_aadhaar_post: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://abhasbx.abdm.gov.in/abha/api/v3*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ABHAEnrollmentApi* | [**api_v3_enrollment_auth_by_aadhaar_post**](docs/ABHAEnrollmentApi.md#api_v3_enrollment_auth_by_aadhaar_post) | **POST** /api/v3/enrollment/auth/byAadhaar | AUTH - OF AADHAAR OTP FOR PARENT VERIFICATION
*ABHAEnrollmentApi* | [**api_v3_enrollment_auth_by_abdm_post**](docs/ABHAEnrollmentApi.md#api_v3_enrollment_auth_by_abdm_post) | **POST** /api/v3/enrollment/auth/byAbdm | VERIFY - EMAIL, MOBILE UPDATE
*ABHAEnrollmentApi* | [**api_v3_enrollment_enrol_by_aadhaar_post**](docs/ABHAEnrollmentApi.md#api_v3_enrollment_enrol_by_aadhaar_post) | **POST** /api/v3/enrollment/enrol/byAadhaar | ENROL - BY AADHAAR VERIFICATION
*ABHAEnrollmentApi* | [**api_v3_enrollment_enrol_by_document_post**](docs/ABHAEnrollmentApi.md#api_v3_enrollment_enrol_by_document_post) | **POST** /api/v3/enrollment/enrol/byDocument | ENROL - BY DOCUMENT
*ABHAEnrollmentApi* | [**api_v3_enrollment_enrol_suggestion_get**](docs/ABHAEnrollmentApi.md#api_v3_enrollment_enrol_suggestion_get) | **GET** /api/v3/enrollment/enrol/suggestion | SUGESSTION
*ABHAEnrollmentApi* | [**api_v3_enrollment_request_otp_post**](docs/ABHAEnrollmentApi.md#api_v3_enrollment_request_otp_post) | **POST** /api/v3/enrollment/request/otp | REQUEST - OTP FOR ENROLLMENT, UPDATE MOBILE and UPDATE EMAIL


## Documentation For Models



<a id="documentation-for-authorization"></a>
## Documentation For Authorization

Endpoints do not require authorization.


## Author




